This is the mail archive of the libc-ports@sources.redhat.com mailing list for the libc-ports project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH] Update kernel-features.h for new syscalls on alpha


The patch updates kernel-features.h given the recent addition of many
syscalls on alpha.

I've send this to libc-alpha, since kernel-features.h is in the main
glibc.git tree, but also CC'd libc-ports since it concerns alpha. Let
me know if this is the correct protocol.

Please review and commit.

Thanks,
Matt Turner
---
 sysdeps/unix/sysv/linux/kernel-features.h |   27 +++++++++++++++++----------
 1 files changed, 17 insertions(+), 10 deletions(-)

diff --git a/sysdeps/unix/sysv/linux/kernel-features.h b/sysdeps/unix/sysv/linux/kernel-features.h
index f48e644..7b08a0e 100644
--- a/sysdeps/unix/sysv/linux/kernel-features.h
+++ b/sysdeps/unix/sysv/linux/kernel-features.h
@@ -488,18 +488,20 @@
 #endif
 
 /* Support for fallocate was added in 2.6.23, on s390
-   only after 2.6.23-rc1.  */
+   only after 2.6.23-rc1, on alpha only after 2.6.33-rc1.  */
 #if __LINUX_KERNEL_VERSION >= 0x020617 \
     && ((!defined __s390__ && !defined __alpha__) \
-	|| (__LINUX_KERNEL_VERSION >= 0x020618 && defined __s390__))
+    || (__LINUX_KERNEL_VERSION >= 0x020618 && defined __s390__) \
+    || (__LINUX_KERNEL_VERSION >= 0x020621 && defined __alpha__))
 # define __ASSUME_FALLOCATE	1
 #endif
 
 /* Support for various CLOEXEC and NONBLOCK flags was added for x86,
-   x86-64, PPC, IA-64, SPARC< and S390 in 2.6.23.  */
+   x86-64, PPC, IA-64, SPARC, and S390, alpha in 2.6.23.  */
 #if __LINUX_KERNEL_VERSION >= 0x020617 \
     && (defined __i386__ || defined __x86_64__ || defined __powerpc__ \
-	|| defined __ia64__ || defined __sparc__ || defined __s390__)
+    || defined __ia64__ || defined __sparc__ || defined __s390__ \
+    || defined __alpha__)
 # define __ASSUME_O_CLOEXEC	1
 #endif
 
@@ -509,10 +511,11 @@
 #endif
 
 /* Support for various CLOEXEC and NONBLOCK flags was added for x86,
-   x86-64, PPC, IA-64, and SPARC in 2.6.27.  */
+   x86-64, PPC, IA-64, and SPARC in 2.6.27, on alpha only after 2.6.33-r1.  */
 #if __LINUX_KERNEL_VERSION >= 0x02061b \
     && (defined __i386__ || defined __x86_64__ || defined __powerpc__ \
-	|| defined __ia64__ || defined __sparc__ || defined __s390__)
+    || defined __ia64__ || defined __sparc__ || defined __s390__) \
+    || (__LINUX_KERNEL_VERSION >= 0x020621 && defined __alpha__)
 # define __ASSUME_SOCK_CLOEXEC	1
 # define __ASSUME_IN_NONBLOCK	1
 # define __ASSUME_PIPE2		1
@@ -520,10 +523,12 @@
 # define __ASSUME_SIGNALFD4	1
 #endif
 
-/* Support for the accept4 syscall was added in 2.6.28.  */
+/* Support for the accept4 syscall was added in 2.6.28, on alpha only
+   after 2.6.33-rc1.  */
 #if __LINUX_KERNEL_VERSION >= 0x02061c \
     && (defined __i386__ || defined __x86_64__ || defined __powerpc__ \
-	|| defined __sparc__ || defined __s390__)
+    || defined __sparc__ || defined __s390__) \
+    || (__LINUX_KERNEL_VERSION >= 0x020621 && defined __alpha__)
 # define __ASSUME_ACCEPT4	1
 #endif
 
@@ -537,8 +542,10 @@
 # define __ASSUME_AT_RANDOM	1
 #endif
 
-/* Support for preadv and pwritev was added in 2.6.30.  */
-#if __LINUX_KERNEL_VERSION >= 0x02061e
+/* Support for preadv and pwritev was added in 2.6.30, on alpha only
+   after 2.6.33-r1.  */
+#if __LINUX_KERNEL_VERSION >= 0x02061e && (!defined __alpha__ \
+    || (__LINUX_KERNEL_VERSION >= 0x020621 && defined __alpha__))
 # define __ASSUME_PREADV	1
 # define __ASSUME_PWRITEV	1
 #endif
-- 
1.6.4.4


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]